// generated 2009-04-30
// grep "public X[Dialog,Widget]" *.h | awk '{print "CLASSITEM("$2")"}' > getscreen_classlist.h
CLASSITEM(absoluteCalendarItem)
CLASSITEM(account1099)
CLASSITEM(accountingPeriod)
CLASSITEM(accountingPeriods)
CLASSITEM(accountingYearPeriod)
CLASSITEM(accountingYearPeriods)
CLASSITEM(accountNumber)
CLASSITEM(accountNumbers)
CLASSITEM(addPoComment)
CLASSITEM(addresses)
CLASSITEM(address)
CLASSITEM(adjustmentTrans)
CLASSITEM(adjustInvValue)
CLASSITEM(allocateARCreditMemo)
CLASSITEM(allocateReservations)
CLASSITEM(apAccountAssignment)
CLASSITEM(apAccountAssignments)
CLASSITEM(apCreditMemoApplication)
CLASSITEM(apOpenItem)
CLASSITEM(applyAPCreditMemo)
CLASSITEM(applyARCreditMemo)
CLASSITEM(applyDiscount)
CLASSITEM(apWorkBench)
CLASSITEM(arAccountAssignment)
CLASSITEM(arAccountAssignments)
CLASSITEM(archRestoreSalesHistory)
CLASSITEM(arCreditMemoApplication)
CLASSITEM(arOpenItem)
CLASSITEM(arWorkBench)
CLASSITEM(assessFinanceCharges)
CLASSITEM(assignClassCodeToPlannerCode)
CLASSITEM(assignItemToPlannerCode)
CLASSITEM(assignLotSerial)
CLASSITEM(bankAccount)
CLASSITEM(bankAccounts)
CLASSITEM(bankAdjustmentEditList)
CLASSITEM(bankAdjustment)
CLASSITEM(bankAdjustmentType)
CLASSITEM(bankAdjustmentTypes)
CLASSITEM(BOM)
CLASSITEM(bomItem)
CLASSITEM(bomList)
CLASSITEM(budgets)
CLASSITEM(buyCard)
CLASSITEM(calendar)
CLASSITEM(calendars)
CLASSITEM(cashReceipt)
CLASSITEM(cashReceiptItem)
CLASSITEM(cashReceiptMiscDistrib)
CLASSITEM(cashReceiptsEditList)
CLASSITEM(changePoitemQty)
CLASSITEM(changeWoQty)
CLASSITEM(characteristicAssignment)
CLASSITEM(characteristic)
CLASSITEM(characteristicPrice)
CLASSITEM(characteristics)
CLASSITEM(checkFormat)
CLASSITEM(checkFormats)
CLASSITEM(check)
CLASSITEM(classCode)
CLASSITEM(classCodes)
CLASSITEM(classCodeTax)
CLASSITEM(closePurchaseOrder)
CLASSITEM(closeWo)
CLASSITEM(commentType)
CLASSITEM(commentTypes)
CLASSITEM(companies)
CLASSITEM(company)
CLASSITEM(configureCC)
CLASSITEM(configureCRM)
CLASSITEM(configureEncryption)
CLASSITEM(configureGL)
CLASSITEM(configureIE)
CLASSITEM(configureIM)
CLASSITEM(configureMS)
CLASSITEM(configurePD)
CLASSITEM(configurePO)
CLASSITEM(configureSO)
CLASSITEM(configureSearchPath)
CLASSITEM(configureWO)
CLASSITEM(confirmAchOK)
CLASSITEM(contact)
CLASSITEM(contacts)
CLASSITEM(contactMerge)
CLASSITEM(contract)
CLASSITEM(contracts)
CLASSITEM(copyBOM)
CLASSITEM(copyBudget)
CLASSITEM(copyContract)
CLASSITEM(copyItem)
CLASSITEM(copyPurchaseOrder)
CLASSITEM(copySalesOrder)
CLASSITEM(copyTransferOrder)
CLASSITEM(correctProductionPosting)
CLASSITEM(costCategories)
CLASSITEM(costCategory)
CLASSITEM(costingElements)
CLASSITEM(countries)
CLASSITEM(country)
CLASSITEM(countSlip)
CLASSITEM(countTag)
CLASSITEM(countTagList)
CLASSITEM(createCountTagsByItem)
CLASSITEM(createCountTagsByParameterList)
CLASSITEM(createCycleCountTags)
CLASSITEM(createInvoices)
CLASSITEM(createItemSitesByClassCode)
CLASSITEM(createLotSerial)
CLASSITEM(createPlannedOrdersByItem)
CLASSITEM(createPlannedOrdersByPlannerCode)
CLASSITEM(createRecurringInvoices)
CLASSITEM(createRecurringItems)
CLASSITEM(creditCard)
CLASSITEM(creditMemoEditList)
CLASSITEM(creditMemo)
CLASSITEM(creditMemoItem)
CLASSITEM(crmaccount)
CLASSITEM(crmaccounts)
CLASSITEM(currencies)
CLASSITEM(currencyConversion)
CLASSITEM(currencyConversions)
CLASSITEM(currency)
CLASSITEM(currencySelect)
CLASSITEM(customCommandArgument)
CLASSITEM(customCommand)
CLASSITEM(customCommands)
CLASSITEM(customerFormAssignment)
CLASSITEM(customerFormAssignments)
CLASSITEM(customerGroup)
CLASSITEM(customerGroups)
CLASSITEM(customer)
CLASSITEM(customers)
CLASSITEM(customerType)
CLASSITEM(customerTypeList)
CLASSITEM(customerTypes)
CLASSITEM(databaseInformation)
CLASSITEM(deletePlannedOrder)
CLASSITEM(deletePlannedOrdersByPlannerCode)
CLASSITEM(department)
CLASSITEM(departments)
CLASSITEM(distributeInventory)
CLASSITEM(distributeToLocation)
CLASSITEM(dspAllocations)
CLASSITEM(dspAPApplications)
CLASSITEM(dspAPOpenItemsByVendor)
CLASSITEM(dspARApplications)
CLASSITEM(dspAROpenItems)
CLASSITEM(dspBacklog)
CLASSITEM(dspBankrecHistory)
CLASSITEM(dspBillingSelections)
CLASSITEM(dspBookings)
CLASSITEM(dspBriefEarnedCommissions)
CLASSITEM(dspBriefSalesHistory)
CLASSITEM(dspCapacityUOMsByClassCode)
CLASSITEM(dspCapacityUOMsByProductCategory)
CLASSITEM(dspCashReceipts)
CLASSITEM(dspCheckRegister)
CLASSITEM(dspCostedIndentedBOM)
CLASSITEM(dspCostedSingleLevelBOM)
CLASSITEM(dspCostedSummarizedBOM)
CLASSITEM(dspCountSlipEditList)
CLASSITEM(dspCountSlipsByWarehouse)
CLASSITEM(dspCountTagEditList)
CLASSITEM(dspCountTagsByClassCode)
CLASSITEM(dspCountTagsByItem)
CLASSITEM(dspCountTagsByWarehouse)
CLASSITEM(dspCustomerARHistory)
CLASSITEM(dspDepositsRegister)
CLASSITEM(dspDetailedInventoryHistoryByLocation)
CLASSITEM(dspDetailedInventoryHistoryByLotSerial)
CLASSITEM(dspEarnedCommissions)
CLASSITEM(dspExpediteExceptionsByPlannerCode)
CLASSITEM(dspExpiredInventoryByClassCode)
CLASSITEM(dspFinancialReport)
CLASSITEM(dspFreightPricesByCustomer)
CLASSITEM(dspFreightPricesByCustomerType)
CLASSITEM(dspFrozenItemSites)
CLASSITEM(dspGLSeries)
CLASSITEM(dspGLTransactions)
CLASSITEM(dspIndentedBOM)
CLASSITEM(dspIndentedWhereUsed)
CLASSITEM(dspInvalidBillsOfMaterials)
CLASSITEM(dspInventoryAvailabilityByCustomerType)
CLASSITEM(dspInventoryAvailabilityByWorkOrder)
CLASSITEM(dspInventoryHistory)
CLASSITEM(dspInventoryLocator)
CLASSITEM(dspInvoiceInformation)
CLASSITEM(dspInvoiceRegister)
CLASSITEM(dspItemCostDetail)
CLASSITEM(dspItemCostHistory)
CLASSITEM(dspItemCostsByClassCode)
CLASSITEM(dspItemCostSummary)
CLASSITEM(dspItemSources)
CLASSITEM(dspItemSourcePrices)
CLASSITEM(dspItemsWithoutItemSources)
CLASSITEM(dspJobCosting)
CLASSITEM(dspMaterialUsageVarianceByBOMItem)
CLASSITEM(dspMaterialUsageVarianceByComponentItem)
CLASSITEM(dspMaterialUsageVarianceByItem)
CLASSITEM(dspMaterialUsageVarianceByWarehouse)
CLASSITEM(dspMaterialUsageVarianceByWorkOrder)
CLASSITEM(dspMRPDetail)
CLASSITEM(dspOrderActivityByProject)
CLASSITEM(dspOrders)
CLASSITEM(dspPartiallyShippedOrders)
CLASSITEM(dspPendingAvailability)
CLASSITEM(dspPendingBOMChanges)
CLASSITEM(dspPlannedOrders)
CLASSITEM(dspPoDeliveryDateVariancesByItem)
CLASSITEM(dspPoDeliveryDateVariancesByVendor)
CLASSITEM(dspPoHistory)
CLASSITEM(dspPoItemReceivingsByDate)
CLASSITEM(dspPoItemReceivingsByItem)
CLASSITEM(dspPoItemReceivingsByVendor)
CLASSITEM(dspPoItemsByDate)
CLASSITEM(dspPoItemsByItem)
CLASSITEM(dspPoItemsByVendor)
CLASSITEM(dspPoPriceVariancesByItem)
CLASSITEM(dspPoPriceVariancesByVendor)
CLASSITEM(dspPoReturnsByVendor)
CLASSITEM(dspPOsByDate)
CLASSITEM(dspPOsByVendor)
CLASSITEM(dspPricesByCustomer)
CLASSITEM(dspPricesByCustomerType)
CLASSITEM(dspPricesByItem)
CLASSITEM(dspPurchaseReqsByItem)
CLASSITEM(dspPurchaseReqsByPlannerCode)
CLASSITEM(dspQOH)
CLASSITEM(dspQOHByLocation)
CLASSITEM(dspQuotesByCustomer)
CLASSITEM(dspQuotesByItem)
CLASSITEM(dspReorderExceptionsByPlannerCode)
CLASSITEM(dspReservations)
CLASSITEM(dspRunningAvailability)
CLASSITEM(dspSalesHistory)
CLASSITEM(dspSalesOrders)
CLASSITEM(dspSalesOrdersByItem)
CLASSITEM(dspSalesOrderStatus)
CLASSITEM(dspShipmentsByDate)
CLASSITEM(dspShipmentsBySalesOrder)
CLASSITEM(dspShipmentsByShipment)
CLASSITEM(dspSingleLevelBOM)
CLASSITEM(dspSingleLevelWhereUsed)
CLASSITEM(dspSlowMovingInventoryByClassCode)
CLASSITEM(dspStandardJournalHistory)
CLASSITEM(dspSubstituteAvailabilityByItem)
CLASSITEM(dspSummarizedBacklogByWarehouse)
CLASSITEM(dspSummarizedBankrecHistory)
CLASSITEM(dspSummarizedBOM)
CLASSITEM(dspSummarizedGLTransactions)
CLASSITEM(dspSummarizedSales)
CLASSITEM(dspTax1099)
CLASSITEM(dspTaxHistory)
CLASSITEM(dspTimePhasedAvailability)
CLASSITEM(dspTimePhasedBookings)
CLASSITEM(dspTimePhasedOpenAPItems)
CLASSITEM(dspTimePhasedOpenARItems)
CLASSITEM(dspTimePhasedSales)
CLASSITEM(dspTimePhasedUsageStatisticsByItem)
CLASSITEM(dspTrialBalances)
CLASSITEM(dspUnbalancedQOHByClassCode)
CLASSITEM(dspUndefinedManufacturedItems)
CLASSITEM(dspUninvoicedReceivings)
CLASSITEM(dspUnusedPurchasedItems)
CLASSITEM(dspUsageStatistics)
CLASSITEM(dspUserPrivileges)
CLASSITEM(dspValidLocationsByItem)
CLASSITEM(dspVendorAPHistory)
CLASSITEM(dspVoucherRegister)
CLASSITEM(dspWoHistoryByClassCode)
CLASSITEM(dspWoHistoryByItem)
CLASSITEM(dspWoHistoryByNumber)
CLASSITEM(dspWoMaterialsByItem)
CLASSITEM(dspWoMaterialsByWorkOrder)
CLASSITEM(dspWoSchedule)
CLASSITEM(duplicateAccountNumbers)
CLASSITEM(editOwners)
CLASSITEM(empGroup)
CLASSITEM(empGroups)
CLASSITEM(employee)
CLASSITEM(employees)
CLASSITEM(enterMiscCount)
CLASSITEM(enterPoitemReceipt)
CLASSITEM(enterPoitemReturn)
CLASSITEM(enterPoReceipt)
CLASSITEM(enterPoReturn)
CLASSITEM(errorLog)
CLASSITEM(eventManager)
CLASSITEM(expenseCategories)
CLASSITEM(expenseCategory)
CLASSITEM(expenseTrans)
CLASSITEM(explodeWo)
CLASSITEM(exportData)
CLASSITEM(externalCCTransaction)
CLASSITEM(externalShipping)
CLASSITEM(externalShippingList)
CLASSITEM(failedPostList)
CLASSITEM(financialLayoutColumns)
CLASSITEM(financialLayoutGroup)
CLASSITEM(financialLayout)
CLASSITEM(financialLayoutItem)
CLASSITEM(financialLayouts)
CLASSITEM(financialLayoutSpecial)
CLASSITEM(firmPlannedOrder)
CLASSITEM(firmPlannedOrdersByPlannerCode)
CLASSITEM(fixACL)
CLASSITEM(fixSerial)
CLASSITEM(form)
CLASSITEM(forms)
CLASSITEM(forwardUpdateAccounts)
CLASSITEM(freightBreakdown)
CLASSITEM(freightClasses)
CLASSITEM(freightClass)
CLASSITEM(getGLDistDate)
CLASSITEM(getLotInfo)
CLASSITEM(glSeries)
CLASSITEM(glSeriesItem)
CLASSITEM(glTransactionDetail)
CLASSITEM(glTransaction)
CLASSITEM(group)
CLASSITEM(groups)
CLASSITEM(honorific)
CLASSITEM(honorifics)
CLASSITEM(hotkey)
CLASSITEM(hotkeys)
CLASSITEM(idleShutdown)
CLASSITEM(image)
CLASSITEM(imageList)
CLASSITEM(images)
CLASSITEM(implodeWo)
CLASSITEM(importData)
CLASSITEM(incidentCategories)
CLASSITEM(incidentCategory)
CLASSITEM(incident)
CLASSITEM(incidentPriorities)
CLASSITEM(incidentPriority)
CLASSITEM(incidentResolution)
CLASSITEM(incidentResolutions)
CLASSITEM(incidentSeverities)
CLASSITEM(incidentSeverity)
CLASSITEM(incidentWorkbench)
CLASSITEM(invoice)
CLASSITEM(invoiceItem)
CLASSITEM(invoiceList)
CLASSITEM(issueLineToShipping)
CLASSITEM(issueToShipping)
CLASSITEM(issueWoMaterialBatch)
CLASSITEM(issueWoMaterialItem)
CLASSITEM(itemAlias)
CLASSITEM(itemAvailabilityWorkbench)
CLASSITEM(itemCost)
CLASSITEM(itemGroup)
CLASSITEM(itemGroups)
CLASSITEM(item)
CLASSITEM(itemImages)
CLASSITEM(itemListPrice)
CLASSITEM(itemPricingSchedule)
CLASSITEM(itemPricingScheduleItem)
CLASSITEM(itemPricingSchedules)
CLASSITEM(items)
CLASSITEM(itemSite)
CLASSITEM(itemSites)
CLASSITEM(itemSource)
CLASSITEM(itemSourceList)
CLASSITEM(itemSourcePrice)
CLASSITEM(itemSourceSearch)
CLASSITEM(itemSubstitute)
CLASSITEM(itemtax)
CLASSITEM(itemUOM)
CLASSITEM(labelForm)
CLASSITEM(labelForms)
CLASSITEM(ledgerControl)
CLASSITEM(listRecurringInvoices)
CLASSITEM(locales)
CLASSITEM(location)
CLASSITEM(locations)
CLASSITEM(lotSerial)
CLASSITEM(lotSerialSequences)
CLASSITEM(lotSerialRegistration)
CLASSITEM(maintainBudget)
CLASSITEM(maintainItemCosts)
CLASSITEM(maintainShipping)
CLASSITEM(massExpireComponent)
CLASSITEM(massReplaceComponent)
CLASSITEM(materialReceiptTrans)
CLASSITEM(metasqls)
CLASSITEM(miscCheck)
CLASSITEM(miscVoucher)
CLASSITEM(openReturnAuthorizations)
CLASSITEM(openSalesOrders)
CLASSITEM(openVouchers)
CLASSITEM(opportunity)
CLASSITEM(opportunityList)
CLASSITEM(opportunitySource)
CLASSITEM(opportunitySources)
CLASSITEM(opportunityStage)
CLASSITEM(opportunityStages)
CLASSITEM(opportunityType)
CLASSITEM(opportunityTypes)
CLASSITEM(package)
CLASSITEM(packages)
CLASSITEM(packingListBatch)
CLASSITEM(plannedOrder)
CLASSITEM(plannerCode)
CLASSITEM(plannerCodes)
CLASSITEM(poLiabilityDistrib)
CLASSITEM(postCashReceipts)
CLASSITEM(postCheck)
CLASSITEM(postChecks)
CLASSITEM(postCostsByClassCode)
CLASSITEM(postCostsByItem)
CLASSITEM(postCountSlips)
CLASSITEM(postCountTags)
CLASSITEM(postCreditMemos)
CLASSITEM(postInvoices)
CLASSITEM(postMiscProduction)
CLASSITEM(postPoReturnCreditMemo)
CLASSITEM(postProduction)
CLASSITEM(postPurchaseOrder)
CLASSITEM(postPurchaseOrdersByAgent)
CLASSITEM(postStandardJournalGroup)
CLASSITEM(postStandardJournal)
CLASSITEM(postVouchers)
CLASSITEM(poType)
CLASSITEM(poTypes)
CLASSITEM(prepareCheckRun)
CLASSITEM(priceList)
CLASSITEM(pricingScheduleAssignment)
CLASSITEM(pricingScheduleAssignments)
CLASSITEM(printCheck)
CLASSITEM(printChecks)
CLASSITEM(printChecksReview)
CLASSITEM(printCreditMemo)
CLASSITEM(printCreditMemos)
CLASSITEM(printInvoice)
CLASSITEM(printInvoices)
CLASSITEM(printItemLabelsByClassCode)
CLASSITEM(printLabelsByInvoice)
CLASSITEM(printLabelsByOrder)
CLASSITEM(printLabelsBySo)
CLASSITEM(printLabelsByTo)
CLASSITEM(printMulticopyDocument)
CLASSITEM(printOptions)
CLASSITEM(printPackingListBatchByShipvia)
CLASSITEM(printPackingList)
CLASSITEM(printPoForm)
CLASSITEM(printToForm)
CLASSITEM(printPurchaseOrder)
CLASSITEM(printPurchaseOrdersByAgent)
CLASSITEM(printRaForm)
CLASSITEM(printShippingForm)
CLASSITEM(printShippingForms)
CLASSITEM(printSoForm)
CLASSITEM(printStatementByCustomer)
CLASSITEM(printStatementsByCustomerType)
CLASSITEM(printVendorForm)
CLASSITEM(printWoForm)
CLASSITEM(printWoPickList)
CLASSITEM(printWoTraveler)
CLASSITEM(productCategories)
CLASSITEM(productCategory)
CLASSITEM(profitCenter)
CLASSITEM(profitCenters)
CLASSITEM(project)
CLASSITEM(projects)
CLASSITEM(projectTypes)
CLASSITEM(prospect)
CLASSITEM(prospects)
CLASSITEM(purchaseOrder)
CLASSITEM(purchaseOrderItem)
CLASSITEM(purchaseRequest)
CLASSITEM(purgeClosedWorkOrders)
CLASSITEM(purgeCreditMemos)
CLASSITEM(purgeInvoices)
CLASSITEM(purgePostedCounts)
CLASSITEM(purgePostedCountSlips)
CLASSITEM(quickRelocateLot)
CLASSITEM(quotes)
CLASSITEM(reasonCode)
CLASSITEM(reasonCodes)
CLASSITEM(reassignClassCodeByClassCode)
CLASSITEM(reassignCustomerTypeByCustomerType)
CLASSITEM(reassignLotSerial)
CLASSITEM(reassignProductCategoryByProductCategory)
CLASSITEM(recallOrders)
CLASSITEM(reconcileBankaccount)
CLASSITEM(registrationKey)
CLASSITEM(rejectCode)
CLASSITEM(rejectCodes)
CLASSITEM(relativeCalendarItem)
CLASSITEM(releasePlannedOrdersByPlannerCode)
CLASSITEM(releaseTransferOrdersByAgent)
CLASSITEM(releaseWorkOrdersByPlannerCode)
CLASSITEM(relocateInventory)
CLASSITEM(reports)
CLASSITEM(reprintCreditMemos)
CLASSITEM(reprintInvoices)
CLASSITEM(reprintMulticopyDocument)
CLASSITEM(reprioritizeWo)
CLASSITEM(reschedulePoitem)
CLASSITEM(rescheduleWo)
CLASSITEM(reserveSalesOrderItem)
CLASSITEM(resetQOHBalances)
CLASSITEM(returnAuthCheck)
CLASSITEM(returnAuthItemLotSerial)
CLASSITEM(returnAuthorization)
CLASSITEM(returnAuthorizationItem)
CLASSITEM(returnAuthorizationWorkbench)
CLASSITEM(returnWoMaterialBatch)
CLASSITEM(returnWoMaterialItem)
CLASSITEM(reverseGLSeries)
CLASSITEM(sale)
CLASSITEM(salesAccount)
CLASSITEM(salesAccounts)
CLASSITEM(salesCategories)
CLASSITEM(salesCategory)
CLASSITEM(sales)
CLASSITEM(salesHistoryInformation)
CLASSITEM(salesOrder)
CLASSITEM(salesOrderInformation)
CLASSITEM(salesOrderItem)
CLASSITEM(salesOrderSimple)
CLASSITEM(salesRep)
CLASSITEM(salesReps)
CLASSITEM(saleType)
CLASSITEM(saleTypes)
CLASSITEM(scrapTrans)
CLASSITEM(scrapWoMaterialFromWIP)
CLASSITEM(scriptEditor)
CLASSITEM(scripts)
CLASSITEM(searchForEmp)
CLASSITEM(selectBankAccount)
CLASSITEM(selectBillingQty)
CLASSITEM(selectedPayments)
CLASSITEM(selectOrderForBilling)
CLASSITEM(selectPayment)
CLASSITEM(selectPayments)
CLASSITEM(selectShippedOrders)
CLASSITEM(setup)
CLASSITEM(shipOrder)
CLASSITEM(shippingChargeType)
CLASSITEM(shippingChargeTypes)
CLASSITEM(shippingForm)
CLASSITEM(shippingForms)
CLASSITEM(shippingInformation)
CLASSITEM(shippingZone)
CLASSITEM(shippingZones)
CLASSITEM(shipTo)
CLASSITEM(shipVia)
CLASSITEM(shipVias)
CLASSITEM(siteType)
CLASSITEM(siteTypes)
CLASSITEM(splitReceipt)
CLASSITEM(standardJournalGroup)
CLASSITEM(standardJournalGroupItem)
CLASSITEM(standardJournalGroups)
CLASSITEM(standardJournal)
CLASSITEM(standardJournalItem)
CLASSITEM(standardJournals)
CLASSITEM(states)
CLASSITEM(subAccntType)
CLASSITEM(subAccntTypes)
CLASSITEM(subaccount)
CLASSITEM(subaccounts)
CLASSITEM(submitAction)
CLASSITEM(submitReport)
CLASSITEM(substituteList)
CLASSITEM(summarizeInvTransByClassCode)
CLASSITEM(syncCompanies)
CLASSITEM(sysLocale)
CLASSITEM(systemMessage)
CLASSITEM(task)
CLASSITEM(taxAuthorities)
CLASSITEM(taxAuthority)
CLASSITEM(taxBreakdown)
CLASSITEM(taxClasses)
CLASSITEM(taxClass)
CLASSITEM(taxCode)
CLASSITEM(taxCodeRate)
CLASSITEM(taxCodes)
CLASSITEM(taxDetail)
CLASSITEM(taxRegistration)
CLASSITEM(taxRegistrations)
CLASSITEM(taxType)
CLASSITEM(taxTypes)
CLASSITEM(taxZone)
CLASSITEM(taxZones)
CLASSITEM(termses)
CLASSITEM(terms)
CLASSITEM(thawItemSitesByClassCode)
CLASSITEM(todoItem)
CLASSITEM(todoListCalendar)
CLASSITEM(todoList)
CLASSITEM(toggleBankrecCleared)
CLASSITEM(transactionInformation)
CLASSITEM(transferOrder)
CLASSITEM(transferOrderItem)
CLASSITEM(transferOrders)
CLASSITEM(transferTrans)
CLASSITEM(transformTrans)
CLASSITEM(uiform)
CLASSITEM(uiforms)
CLASSITEM(unappliedAPCreditMemos)
CLASSITEM(unappliedARCreditMemos)
CLASSITEM(uninvoicedShipments)
CLASSITEM(unpostedCreditMemos)
CLASSITEM(unpostedGlSeries)
CLASSITEM(unpostedGLTransactions)
CLASSITEM(unpostedInvoices)
CLASSITEM(unpostedPoReceipts)
CLASSITEM(unpostedPurchaseOrders)
CLASSITEM(uomConv)
CLASSITEM(uom)
CLASSITEM(uoms)
CLASSITEM(updateABCClass)
CLASSITEM(updateActualCostsByClassCode)
CLASSITEM(updateActualCostsByItem)
CLASSITEM(updateCreditStatusByCustomer)
CLASSITEM(updateCycleCountFrequency)
CLASSITEM(updateItemSiteLeadTimes)
CLASSITEM(updateLateCustCreditStatus)
CLASSITEM(updateListPricesByProductCategory)
CLASSITEM(updateOUTLevelByItem)
CLASSITEM(updateOUTLevelsByClassCode)
CLASSITEM(updateOUTLevels)
CLASSITEM(updatePrices)
CLASSITEM(updateReorderLevels)
CLASSITEM(userCostingElement)
CLASSITEM(user)
CLASSITEM(userList)
CLASSITEM(userPreferences)
CLASSITEM(users)
CLASSITEM(vendorAddress)
CLASSITEM(vendorAddressList)
CLASSITEM(vendor)
CLASSITEM(vendors)
CLASSITEM(vendorPriceList)
CLASSITEM(vendorType)
CLASSITEM(vendorTypes)
CLASSITEM(viewCheckRun)
CLASSITEM(voidChecks)
CLASSITEM(voucher)
CLASSITEM(voucherItemDistrib)
CLASSITEM(voucherItem)
CLASSITEM(voucherMiscDistrib)
CLASSITEM(warehouse)
CLASSITEM(warehouses)
CLASSITEM(warehouseZone)
CLASSITEM(woMaterialItem)
CLASSITEM(workOrder)
CLASSITEM(workOrderMaterials)
CLASSITEM(XDateInputDialog)
CLASSITEM(xsltMap)
CLASSITEM(zeroUncountedCountTagsByWarehouse)
